import { __require as requireX509 } from './x509.mjs';
import { __require as requireAssert } from '../../../assert-plus/assert.mjs';
import { __require as requireLib } from '../../../asn1/lib/index.mjs';
import { __require as requireSafer } from '../../../safer-buffer/safer.mjs';
import { __require as requireAlgs } from '../algs.mjs';
import { __require as requireUtils } from '../utils.mjs';
import { __require as requireKey } from '../key.mjs';
import { __require as requirePrivateKey } from '../private-key.mjs';
import { __require as requirePem } from './pem.mjs';
import { __require as requireIdentity } from '../identity.mjs';
import { __require as requireSignature } from '../signature.mjs';
import { __require as requireCertificate } from '../certificate.mjs';

var x509Pem;
var hasRequiredX509Pem;

function requireX509Pem () {
	if (hasRequiredX509Pem) return x509Pem;
	hasRequiredX509Pem = 1;
	// Copyright 2016 Joyent, Inc.

	var x509 = requireX509();

	x509Pem = {
		read: read,
		verify: x509.verify,
		sign: x509.sign,
		write: write
	};

	var assert = requireAssert();
	requireLib();
	var Buffer = requireSafer().Buffer;
	requireAlgs();
	requireUtils();
	requireKey();
	requirePrivateKey();
	requirePem();
	requireIdentity();
	requireSignature();
	requireCertificate();

	function read(buf, options) {
		if (typeof (buf) !== 'string') {
			assert.buffer(buf, 'buf');
			buf = buf.toString('ascii');
		}

		var lines = buf.trim().split(/[\r\n]+/g);

		var m;
		var si = -1;
		while (!m && si < lines.length) {
			m = lines[++si].match(/*JSSTYLED*/
			    /[-]+[ ]*BEGIN CERTIFICATE[ ]*[-]+/);
		}
		assert.ok(m, 'invalid PEM header');

		var m2;
		var ei = lines.length;
		while (!m2 && ei > 0) {
			m2 = lines[--ei].match(/*JSSTYLED*/
			    /[-]+[ ]*END CERTIFICATE[ ]*[-]+/);
		}
		assert.ok(m2, 'invalid PEM footer');

		lines = lines.slice(si, ei + 1);

		var headers = {};
		while (true) {
			lines = lines.slice(1);
			m = lines[0].match(/*JSSTYLED*/
			    /^([A-Za-z0-9-]+): (.+)$/);
			if (!m)
				break;
			headers[m[1].toLowerCase()] = m[2];
		}

		/* Chop off the first and last lines */
		lines = lines.slice(0, -1).join('');
		buf = Buffer.from(lines, 'base64');

		return (x509.read(buf, options));
	}

	function write(cert, options) {
		var dbuf = x509.write(cert, options);

		var header = 'CERTIFICATE';
		var tmp = dbuf.toString('base64');
		var len = tmp.length + (tmp.length / 64) +
		    18 + 16 + header.length*2 + 10;
		var buf = Buffer.alloc(len);
		var o = 0;
		o += buf.write('-----BEGIN ' + header + '-----\n', o);
		for (var i = 0; i < tmp.length; ) {
			var limit = i + 64;
			if (limit > tmp.length)
				limit = tmp.length;
			o += buf.write(tmp.slice(i, limit), o);
			buf[o++] = 10;
			i = limit;
		}
		o += buf.write('-----END ' + header + '-----\n', o);

		return (buf.slice(0, o));
	}
	return x509Pem;
}

export { requireX509Pem as __require };
