import { getContentToBuild } from './getContnetToBuild.mjs';
import { getRemoteContentToBuild } from './getRemoteContentToBuild.mjs';
import { updateDetailsFileMapConfig2 } from './updateFileMapConfig.mjs';
import { createFile } from '../util/createFile.mjs';
import { createPath } from '../util/createPath.mjs';
import { debugFunction } from '../util/debugFunction.mjs';
import { isFileOrFolderExists } from '../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';

const buildFromConfig = async (config) => {
    debugFunction(config.isDebug, 'start', '[INIT] buildFromConfig');
    let snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    for (const realFilePath in snpFileMapConfig.snpFileMap) {
        // bo sprawdzamy tylko po default reszta powinn być wygenewoana ręcznie lub korzysta tylko z getContent
        // const SNPKeySuffix = "defaulFile"
        for (const SNPKeySuffix in snpFileMapConfig.snpFileMap[realFilePath]) {
            if (SNPKeySuffix === '_') {
                continue;
            }
            const currentFileObject = snpFileMapConfig.snpFileMap[realFilePath][SNPKeySuffix];
            if (!(await isFileOrFolderExists({ isDebug: config.isDebug, filePath: currentFileObject.path }))) {
                await createFile({
                    filePath: createPath(currentFileObject.path),
                    content: '',
                    isDebug: config.isDebug,
                    options: {
                        overwriteFile: true,
                    },
                }).then(async () => {
                    snpFileMapConfig = await updateDetailsFileMapConfig2({
                        config,
                        operation: 'createSuffixFile',
                        realFilePath,
                        SNPKeySuffix: SNPKeySuffix,
                    });
                });
            }
            // Tutaj nie ma potrzeby występowania innych niż default
            if (snpFileMapConfig.fileMap.includes(currentFileObject.SNPSuffixFileName)) {
                const content = await getRemoteContentToBuild({
                    config,
                    snpObject: currentFileObject,
                });
                if (content) {
                    await createFile({
                        filePath: currentFileObject.path,
                        content,
                        options: {
                            overwriteFile: true,
                        },
                    });
                }
            }
        }
        // const updatedSnpFileMapConfig: FileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) =>
        //   parseJSON(bufferData.toString())
        // );
        const realFileObject = snpFileMapConfig.snpFileMap[realFilePath]['_'];
        if (snpFileMapConfig.snpFileMap) {
            const snpSetObject = snpFileMapConfig.snpFileMap[realFilePath];
            const content = await getContentToBuild(snpSetObject);
            if (content) {
                await createFile({
                    filePath: realFileObject.path,
                    content,
                    isDebug: config.isDebug,
                }).then(async () => {
                    snpFileMapConfig = await updateDetailsFileMapConfig2({
                        config,
                        operation: 'createSNPRealFile',
                        realFilePath,
                    });
                });
            }
        }
    }
    debugFunction(config.isDebug, { snpFileMapConfig }, '[INIT] buildFromConfig');
    return { config, snpFileMapConfig };
};

export { buildFromConfig };
