import { updateDetailsFileMapConfig2 } from './updateFileMapConfig.mjs';
import { createPath } from '../util/createPath.mjs';
import { deletePath } from '../util/deletePath.mjs';
import { formatSnp } from '../util/formatSnp.mjs';
import { getRealFilePath } from '../util/getRealFilePath.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';

const cleanUpBeforeUpdate = async (config) => {
    let snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    const fileToClean = [];
    const deletedPath = [];
    try {
        if (snpFileMapConfig.snpFileMap && snpFileMapConfig.fileMap) {
            const createdFileRealName = [];
            for (const SNPSuffixFileName of snpFileMapConfig.fileMap) {
                const realFilePath = getRealFilePath({ config, SNPSuffixFileName });
                const SNPKeySuffix = formatSnp(SNPSuffixFileName, 'key');
                if (!createdFileRealName.includes([realFilePath, SNPKeySuffix])) {
                    createdFileRealName.push([realFilePath, SNPKeySuffix]);
                }
            }
            for (const [realFilePath, SNPKeySuffix] of createdFileRealName) {
                fileToClean.push(snpFileMapConfig.snpFileMap[realFilePath][SNPKeySuffix]);
                if (!fileToClean.includes(snpFileMapConfig.snpFileMap[realFilePath]['_'])) {
                    fileToClean.push(snpFileMapConfig.snpFileMap[realFilePath]['_']);
                }
            }
        }
        for (const snpFile of fileToClean) {
            await deletePath(createPath(snpFile.path), config.isDebug)
                .then(async () => {
                snpFileMapConfig = await updateDetailsFileMapConfig2({
                    snpFileMapConfig,
                    config,
                    operation: 'deleteFile',
                    SNPKeySuffix: snpFile.SNPKeySuffix,
                    // realFileName: snpFile.realFileName,
                    realFilePath: snpFile.realFilePath,
                });
                return snpFile.path;
            })
                .then((path) => {
                deletedPath.push(path);
            });
        }
        snpFileMapConfig = await updateDetailsFileMapConfig2({
            snpFileMapConfig,
            config,
            operation: 'removeFileMap',
        });
        return { config, deletedPath, snpFileMapConfig };
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
};

export { cleanUpBeforeUpdate };
