import { createCatalog } from '../util/createCatalog.mjs';
import { createFile } from '../util/createFile.mjs';
import { debugFunction } from '../util/debugFunction.mjs';
import { isFileOrFolderExists } from '../util/isFileOrFolderExists.mjs';
import { objectToBuffer } from '../util/objectToBuffer.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';
import { wgetAsync } from '../util/wget.mjs';

async function downloadConfig(config) {
    debugFunction(config.isDebug, '=== SNP INIT ===', '[INIT] downloadConfig');
    const snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    try {
        debugFunction(config.isDebug, {
            remoteRootRepositoryUrl: config.remoteRootRepositoryUrl,
            remoteRepository: config.remoteRepository,
            fileName: config.REPOSITORY_MAP_FILE_NAME,
            remoteFileMapURL: config.remoteFileMapURL,
        }, '[INIT - downloadConfig]');
        if (!(await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.temporaryFolder }))) {
            await createCatalog(config.temporaryFolder);
        }
        // TODO [SC-18] Ensure temporaryFolder config is nesesery
        return await wgetAsync(config.remoteFileMapURL, config.temporaryFolder)
            .then(async (snpFileMapConfigContent) => {
            let currentConfig = {};
            const downloadContent = parseJSON(snpFileMapConfigContent);
            currentConfig = {
                ...snpFileMapConfig,
                ...downloadContent,
            };
            const combinedConfig = currentConfig;
            if (!combinedConfig.createdFileMap) {
                combinedConfig.createdFileMap = [];
            }
            if (!combinedConfig.snpFileMap) {
                combinedConfig.snpFileMap = {};
            }
            await createFile({
                filePath: config.snpFileMapConfig,
                content: objectToBuffer(combinedConfig),
                options: {
                    overwriteFile: true,
                },
            });
            return { combinedConfig, downloadContent };
        })
            .then(({ combinedConfig, downloadContent }) => {
            debugFunction(config.isDebug, { ...config, templateVersion: combinedConfig.templateVersion }, '[INIT] downloadConfig - end');
            return {
                config: { ...config, templateVersion: combinedConfig.templateVersion },
                snpFileMapConfig: combinedConfig,
                downloadContent,
            };
        });
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
}

export { downloadConfig };
