import { cleanUpFiles } from './__tests__/cleanForTests.mjs';
import { mockConfig, mockSnpFileMapConfig } from './__tests__/const.mjs';
import { searchFilesInDirectory } from './__tests__/searchFilesInDirectory.mjs';
import { downloadConfig } from './downloadConfig.mjs';
import { createFile } from '../util/createFile.mjs';

describe('downloadConfig', () => {
    let config;
    let snpFileMapConfig;
    beforeEach(async () => {
        config = { ...mockConfig.step.createConfigFile };
        snpFileMapConfig = { ...mockSnpFileMapConfig.step.createConfigFile };
        await cleanUpFiles({
            snpCatalog: config.snpCatalog,
            directoryPath: config.projectCatalog,
            isDebug: config.isDebug,
        });
    });
    afterEach(async () => {
        await cleanUpFiles({
            snpCatalog: config.snpCatalog,
            directoryPath: config.projectCatalog,
            isDebug: config.isDebug,
        });
    });
    it('should return correct content with only snpConfigFile', async () => {
        await createFile({
            filePath: config.snpConfigFile,
            content: JSON.stringify(config),
        });
        const result = await downloadConfig(config);
        const allFiles = await searchFilesInDirectory({
            directoryPath: config.projectCatalog,
            excludedFileNames: ['.DS_Store'],
            excludedPhrases: ['.backup'],
        });
        expect({ ...result, allFiles }).toStrictEqual({
            config: {
                ...mockConfig.step.downloadConfigFile.forInit,
            },
            downloadContent: mockSnpFileMapConfig.step.init,
            snpFileMapConfig: mockSnpFileMapConfig.step.downloadConfigFile.forInit,
            allFiles: [
                './test/mockProject/.snp/repositoryMap.json',
                './test/mockProject/.snp/snp.config.json',
                './test/mockProject/.snp/temporary/repositoryMap.json',
            ],
        });
    });
    it('should return correct content with both configs file', async () => {
        await createFile({
            filePath: config.snpConfigFile,
            content: JSON.stringify(config),
        });
        await createFile({
            filePath: config.snpFileMapConfig,
            content: JSON.stringify(snpFileMapConfig),
        });
        const result = await downloadConfig(config);
        const allFiles = await searchFilesInDirectory({
            directoryPath: config.projectCatalog,
            excludedFileNames: ['.DS_Store'],
            excludedPhrases: ['.backup'],
        });
        expect({ ...result, allFiles }).toStrictEqual({
            config: {
                ...mockConfig.step.downloadConfigFile.forInit,
            },
            downloadContent: mockSnpFileMapConfig.step.init,
            snpFileMapConfig: mockSnpFileMapConfig.step.downloadConfigFile.forInit,
            allFiles: [
                './test/mockProject/.snp/repositoryMap.json',
                './test/mockProject/.snp/snp.config.json',
                './test/mockProject/.snp/temporary/repositoryMap.json',
            ],
        });
    });
    it('should return correct content with both configs file', async () => {
        config = {
            ...config,
            remoteFileMapURL: 'https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/test/mockUpdatedTemplate/templateCatalog/repositoryMap.json',
            remoteRepository: 'https://github.com/SebastianWesolowski/s-update-manager/tree/dev/test/mockUpdatedTemplate',
            remoteRootRepositoryUrl: 'https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/tree/dev/test/mockUpdatedTemplate',
        };
        await createFile({
            filePath: config.snpConfigFile,
            content: JSON.stringify(config),
        });
        await createFile({
            filePath: config.snpFileMapConfig,
            content: JSON.stringify(snpFileMapConfig),
        });
        const result = await downloadConfig(config);
        const allFiles = await searchFilesInDirectory({
            directoryPath: config.projectCatalog,
            excludedFileNames: ['.DS_Store'],
            excludedPhrases: ['.backup'],
        });
        expect({ ...result, allFiles }).toStrictEqual({
            config: {
                ...mockConfig.step.downloadConfigFile.forUpdate,
            },
            downloadContent: mockSnpFileMapConfig.step.downloadConfigFile.downloaded,
            snpFileMapConfig: mockSnpFileMapConfig.step.downloadConfigFile.updated,
            allFiles: [
                './test/mockProject/.snp/repositoryMap.json',
                './test/mockProject/.snp/snp.config.json',
                './test/mockProject/.snp/temporary/repositoryMap.json',
            ],
        });
    });
});
