import { cleanUpFiles } from './__tests__/cleanForTests.mjs';
import { mockConfig, mockSnpFileMapConfig } from './__tests__/const.mjs';
import { searchFilesInDirectory } from './__tests__/searchFilesInDirectory.mjs';
import { prepareBaseSnpFileMap } from './prepareBaseFile.mjs';
import { createFile } from '../util/createFile.mjs';

describe('prepareBaseSnpFileMap', () => {
    let config;
    let snpFileMapConfig;
    beforeEach(async () => {
        config = { ...mockConfig.step.downloadConfigFile.forInit };
        snpFileMapConfig = { ...mockSnpFileMapConfig.step.downloadConfigFile.forInit };
        await cleanUpFiles({
            snpCatalog: config.snpCatalog,
            directoryPath: config.projectCatalog,
            isDebug: config.isDebug,
        });
    });
    afterEach(async () => {
        await cleanUpFiles({
            snpCatalog: config.snpCatalog,
            directoryPath: config.projectCatalog,
            isDebug: config.isDebug,
        });
    });
    it('should return correct content', async () => {
        await createFile({
            filePath: config.snpConfigFile,
            content: JSON.stringify(config),
        });
        await createFile({
            filePath: config.snpFileMapConfig,
            content: JSON.stringify(snpFileMapConfig),
        });
        const result = await prepareBaseSnpFileMap(config);
        const allFiles = await searchFilesInDirectory({
            directoryPath: config.projectCatalog,
            excludedFileNames: ['.DS_Store'],
            excludedPhrases: ['.backup'],
        });
        expect({ ...result, allFiles }).toStrictEqual({
            config: mockConfig.step.createConfigFile,
            snpFileMapConfig: mockSnpFileMapConfig.step.prepareBaseSnpFileMap,
            allFiles: ['./test/mockProject/.snp/repositoryMap.json', './test/mockProject/.snp/snp.config.json'],
        });
    });
});
