import semver from '../../../node_modules/semver/index.mjs';
import { createFile } from '../../util/createFile.mjs';
import { debugFunction } from '../../util/debugFunction.mjs';
import { isFileOrFolderExists } from '../../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../../util/parseJSON.mjs';
import { readFile } from '../../util/readFile.mjs';

const bumpVersion = async (templateConfig) => {
    debugFunction(templateConfig.isDebug, { templateConfig }, '[PrepareTemplate] Bump Version');
    const repositoryMapFileConfig = await readFile(templateConfig.repositoryMapFilePath).then(async (bufferData) => parseJSON(bufferData.toString()));
    const currentVersion = repositoryMapFileConfig.templateVersion;
    if (!templateConfig.bumpVersion) {
        debugFunction(templateConfig.isDebug, { templateConfig }, `[PrepareTemplate] END Bump Version - stay with current version, ${currentVersion}`);
        return { templateConfig };
    }
    if (await isFileOrFolderExists({ isDebug: templateConfig.isDebug, filePath: templateConfig.repositoryMapFilePath })) {
        const safeCurrentVersion = currentVersion || '1.0.0';
        repositoryMapFileConfig.templateVersion = semver.inc(safeCurrentVersion, 'patch') || '1.0.0';
    }
    templateConfig = { ...templateConfig, ...repositoryMapFileConfig };
    await createFile({
        filePath: templateConfig.repositoryMapFilePath,
        content: JSON.stringify(templateConfig),
        isDebug: templateConfig.isDebug,
        options: {
            overwriteFile: true,
        },
    });
    debugFunction(templateConfig.isDebug, { templateConfig }, '[PrepareTemplate] END Bump Version');
    return { templateConfig };
};

export { bumpVersion };
