import { clearDirectory } from '../../util/clearDirectory.mjs';
import { createFile } from '../../util/createFile.mjs';
import { debugFunction } from '../../util/debugFunction.mjs';
import { isFileOrFolderExists } from '../../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../../util/parseJSON.mjs';
import { readFile } from '../../util/readFile.mjs';

const cleanUpTemplate = async (templateConfig) => {
    debugFunction(templateConfig.isDebug, { templateConfig }, '[PrepareTemplate] cleanUpTemplate');
    let repositoryMapFileConfig = null;
    if (await isFileOrFolderExists({ isDebug: templateConfig.isDebug, filePath: templateConfig.templateCatalogPath })) {
        if (await isFileOrFolderExists({ isDebug: templateConfig.isDebug, filePath: templateConfig.repositoryMapFilePath })) {
            repositoryMapFileConfig = await readFile(templateConfig.repositoryMapFilePath).then(async (bufferData) => parseJSON(bufferData.toString()));
        }
        await clearDirectory(templateConfig.templateCatalogPath);
        const newContent = repositoryMapFileConfig;
        if (newContent !== null) {
            newContent.fileMap = [];
            newContent.templateFileList = [];
            newContent.rootPathFileList = [];
            await createFile({
                filePath: templateConfig.repositoryMapFilePath,
                content: JSON.stringify(newContent),
                isDebug: templateConfig.isDebug,
                options: {
                    overwriteFile: true,
                },
            });
        }
    }
    debugFunction(templateConfig.isDebug, { templateConfig }, '[PrepareTemplate] end cleanUpTemplate');
    return { templateConfig };
};

export { cleanUpTemplate };
