import { updateDetailsFileMapConfig2 } from './updateFileMapConfig.mjs';
import { createPath } from '../util/createPath.mjs';
import { debugFunction } from '../util/debugFunction.mjs';
import { formatSnp } from '../util/formatSnp.mjs';
import { isFileOrFolderExists } from '../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../util/parseJSON.mjs';
import { readFile } from '../util/readFile.mjs';

async function scanExtraFile(config) {
    debugFunction(config.isDebug, 'start', '[INIT] scanExtraFile');
    let snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    if (snpFileMapConfig.snpFileMap) {
        for (const SNPKeySuffix of config.availableSNPKeySuffix) {
            if (SNPKeySuffix === 'defaultFile') {
                continue;
            }
            for (const [realFilePath] of Object.entries(snpFileMapConfig.snpFileMap || {})) {
                const snpSuffix = formatSnp(SNPKeySuffix, 'suffix');
                const SNPSuffixFilePath = createPath([config.snpCatalog, config.templateCatalogName, realFilePath + snpSuffix]);
                if (await isFileOrFolderExists({ isDebug: config.isDebug, filePath: SNPSuffixFilePath })) {
                    const SNPSuffixFileName = createPath([realFilePath + snpSuffix]);
                    snpFileMapConfig = await updateDetailsFileMapConfig2({
                        snpFileMapConfig,
                        config,
                        operation: 'addConfigSuffixFile',
                        SNPKeySuffix,
                        SNPSuffixFileName,
                        isCreated: true,
                        path: SNPSuffixFilePath,
                        realFilePath,
                        realPath: createPath([config.projectCatalog, realFilePath]),
                        templateVersion: snpFileMapConfig.templateVersion,
                    });
                }
            }
        }
    }
    debugFunction(config.isDebug, config, '[INIT] scanExtraFile - end');
    return { config, snpFileMapConfig };
}

export { scanExtraFile };
