#!/usr/bin/env node
import minimist from '../node_modules/minimist/index.mjs';
import { cleanUpSinglePath, cleanUpSpecificFiles } from './feature/__tests__/cleanForTests.mjs';
import { searchFilesInDirectory } from './feature/__tests__/searchFilesInDirectory.mjs';
import { buildFromConfig } from './feature/buildFromConfig.mjs';
import { cleanUp } from './feature/cleanUp.mjs';
import { getConfig } from './feature/config/defaultConfig.mjs';
import { createConfigFile } from './feature/createConfigFile.mjs';
import { downloadConfig } from './feature/downloadConfig.mjs';
import { prepareBaseSnpFileMap } from './feature/prepareBaseFile.mjs';
import { scanExtraFile } from './feature/scanExtraFile.mjs';
import { debugFunction } from './util/debugFunction.mjs';
import { isFileOrFolderExists } from './util/isFileOrFolderExists.mjs';

const init = async (args) => {
    const config = await getConfig(args);
    if ((await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.snpFileMapConfig })) &&
        (await isFileOrFolderExists({ isDebug: config.isDebug, filePath: config.snpConfigFile }))) {
        if (process.env.SDEBUG !== 'true') {
            throw new Error('Config file exists, use build script or update');
        }
    }
    if (process.env.SDEBUG === 'true') {
        await cleanUpSinglePath({
            path: config.snpCatalog,
            isDebug: config.isDebug,
        });
        const allFiles = await searchFilesInDirectory({
            directoryPath: config.projectCatalog,
            excludedFileNames: ['.gitignore', 'package.json'],
        });
        await cleanUpSpecificFiles({ files: allFiles, isDebug: config.isDebug });
    }
    debugFunction(config.isDebug, '=== Start SNP INIT ===', '[INIT]');
    return config;
};
const args = minimist(process.argv.slice(2));
let finalConfig = {
    isDebug: false,
};
init(args)
    .then((config) => {
    finalConfig = config;
    return createConfigFile(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return downloadConfig(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return prepareBaseSnpFileMap(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return scanExtraFile(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return buildFromConfig(config);
})
    .then(({ config }) => {
    finalConfig = config;
    return cleanUp(config);
})
    .finally(() => {
    debugFunction(finalConfig?.isDebug, { finalConfig }, '[INIT] final config');
    debugFunction(finalConfig?.isDebug, '=== final SNP INIT ===');
});

export { init };
