#!/usr/bin/env node
import minimist from '../node_modules/minimist/index.mjs';
import { defaultRepositoryMapFileConfig } from './feature/config/const.mjs';
import { getTemplateConfig } from './feature/config/defaultTemplateConfig.mjs';
import { bumpVersion } from './feature/prepareTemplate/bumpVersion.mjs';
import { cleanUpTemplate } from './feature/prepareTemplate/cleanUpTemplate.mjs';
import { prepareFileList } from './feature/prepareTemplate/prepareFileList.mjs';
import { scanProjectFolder } from './feature/prepareTemplate/scanProjectFolder.mjs';
import { updateTemplateConfig } from './feature/prepareTemplate/updateTemplateConfig.mjs';
import { createCatalog } from './util/createCatalog.mjs';
import { createFile } from './util/createFile.mjs';
import { debugFunction } from './util/debugFunction.mjs';
import { formatJsonWithPrettier } from './util/formatPrettier.mjs';
import { isFileOrFolderExists } from './util/isFileOrFolderExists.mjs';

const prepareTemplate = async (args) => {
    const templateConfig = getTemplateConfig(args);
    debugFunction(templateConfig.isDebug, '=== Start prepare template ===', '[PrepareTemplate]');
    // TODO improve develop preces with mock catalog
    if (!(await isFileOrFolderExists({ isDebug: templateConfig.isDebug, filePath: templateConfig.templateCatalogPath })) ||
        process.env.SDEBUG !== 'true') {
        await createCatalog(templateConfig.templateCatalogPath);
    }
    if (((await isFileOrFolderExists({ isDebug: templateConfig.isDebug, filePath: templateConfig.templateCatalogPath })) &&
        !(await isFileOrFolderExists({
            isDebug: templateConfig.isDebug,
            filePath: templateConfig.repositoryMapFilePath,
        }))) ||
        process.env.SDEBUG !== 'true') {
        debugFunction(templateConfig.isDebug, `isFileOrFolderExists ${templateConfig.repositoryMapFilePath}`, '[PrepareTemplate]');
        debugFunction(templateConfig.isDebug, templateConfig, '[PrepareTemplate]');
        await createFile({
            filePath: templateConfig.repositoryMapFilePath,
            content: JSON.stringify(defaultRepositoryMapFileConfig),
            isDebug: templateConfig.isDebug,
            options: {
                overwriteFile: true,
            },
        });
        templateConfig.bumpVersion = false;
    }
    debugFunction(templateConfig.isDebug, templateConfig, '[PrepareTemplate] END init');
    return { templateConfig };
};
const args = minimist(process.argv.slice(2));
let finalConfig = {
    isDebug: false,
};
prepareTemplate(args)
    .then(({ templateConfig }) => {
    finalConfig = templateConfig;
    return bumpVersion(templateConfig);
})
    .then(({ templateConfig }) => {
    finalConfig = templateConfig;
    return cleanUpTemplate(templateConfig);
})
    .then(({ templateConfig }) => {
    finalConfig = templateConfig;
    return scanProjectFolder(templateConfig);
})
    .then(({ templateConfig, templateFileList }) => {
    finalConfig = templateConfig;
    return prepareFileList({ templateConfig, templateFileList });
})
    .then(({ templateConfig, templateFileList, fileList, rootPathFileList }) => {
    finalConfig = templateConfig;
    return updateTemplateConfig({ templateConfig, fileList, templateFileList, rootPathFileList });
})
    .then(async ({ templateConfig }) => {
    await formatJsonWithPrettier(templateConfig.repositoryMapFilePath);
})
    .finally(() => {
    debugFunction(finalConfig?.isDebug, { finalConfig }, '[PrepareTemplate] final config');
    debugFunction(finalConfig?.isDebug, '=== Final prepare template ===', '[PrepareTemplate]');
});

export { prepareTemplate };
