import { getRemoteFileMapURL } from './getRemoteFileMapURL.mjs';
import { cleanUpFiles } from '../../feature/__tests__/cleanForTests.mjs';
import { mockConfig } from '../../feature/__tests__/const.mjs';
import { createFile } from '../createFile.mjs';

describe('getRemoteFileMapURL', () => {
    let config;
    beforeEach(async () => {
        config = { ...mockConfig.step.createConfigFile };
        await cleanUpFiles({
            snpCatalog: config.snpCatalog,
            directoryPath: config.projectCatalog,
            isDebug: config.isDebug,
        });
        await createFile({
            filePath: config.snpConfigFile,
            content: JSON.stringify(config),
        });
    });
    afterEach(async () => {
        await cleanUpFiles({
            snpCatalog: config.snpCatalog,
            directoryPath: config.projectCatalog,
            isDebug: config.isDebug,
        });
    });
    it('should return correct URL for GitHub root folder', () => {
        const mockConfig = {
            remoteRepository: 'https://github.com/SebastianWesolowski/s-update-manager/tree/dev/template/node',
            templateCatalogName: 'templateCatalog',
        };
        config = { ...config, ...mockConfig };
        const result = getRemoteFileMapURL(config);
        expect(result).toBe('https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/template/node/templateCatalog/repositoryMap.json');
    });
    it('should return correct URL for GitHub nested folder', () => {
        const mockConfig = {
            remoteRepository: 'https://github.com/SebastianWesolowski/s-update-manager/tree/dev/template/node/templateCatalog',
            templateCatalogName: 'templateCatalog',
        };
        config = { ...config, ...mockConfig };
        const result = getRemoteFileMapURL(config);
        expect(result).toBe('https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/template/node/templateCatalog/repositoryMap.json');
    });
    it('should return correct URL for GitHub nested folder', () => {
        const mockConfig = {
            remoteRepository: 'https://github.com/SebastianWesolowski/s-update-manager/tree/dev/test/testTemplate',
            templateCatalogName: 'templateCatalog',
        };
        config = { ...config, ...mockConfig };
        const result = getRemoteFileMapURL(config);
        expect(result).toBe('https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/test/testTemplate/templateCatalog/repositoryMap.json');
    });
    it('should return correct URL for GitHub file path', () => {
        const mockConfig = {
            remoteRepository: 'https://github.com/SebastianWesolowski/s-update-manager/tree/dev/template/node/templateCatalog/repositoryMap.json',
            templateCatalogName: 'templateCatalog',
        };
        config = { ...config, ...mockConfig };
        const result = getRemoteFileMapURL(config);
        expect(result).toBe('https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/template/node/templateCatalog/repositoryMap.json');
    });
    it('should return correct URL for raw data', () => {
        const mockConfig = {
            remoteRepository: 'https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/template/node/templateCatalog/repositoryMap.json',
            templateCatalogName: 'templateCatalog',
        };
        config = { ...config, ...mockConfig };
        const result = getRemoteFileMapURL(config);
        expect(result).toBe('https://raw.githubusercontent.com/SebastianWesolowski/s-update-manager/dev/template/node/templateCatalog/repositoryMap.json');
    });
});
